==> hinemos_src-2.2.2.tar.gz: SnmpEJB/src/com/clustercontrol/snmp/bean/MonitorSnmpInfo.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.snmp.bean;

import com.clustercontrol.bean.ConvertValueConstant;
import com.clustercontrol.monitor.run.bean.MonitorCheckInfo;

/**
 * SNMP監視情報クラスです。
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class MonitorSnmpInfo extends MonitorCheckInfo
{
	protected java.lang.String communityName;
	protected java.lang.Integer convertFlg = Integer.valueOf(ConvertValueConstant.TYPE_DELTA);
	protected java.lang.String snmpOid;

   public MonitorSnmpInfo()
   {
   }

   public java.lang.String getCommunityName()
   {
      return this.communityName;
   }
   public void setCommunityName( java.lang.String communityName )
   {
      this.communityName = communityName;
   }
   
   public java.lang.Integer getConvertFlg()
   {
      return this.convertFlg;
   }
   public void setConvertFlg( java.lang.Integer convertFlg )
   {
      this.convertFlg = convertFlg;
   }

   public java.lang.String getSnmpOid()
   {
      return this.snmpOid;
   }
   public void setSnmpOid( java.lang.String snmpOid )
   {
      this.snmpOid = snmpOid;
   }
}

==> hinemos_src-2.3.0.tar.gz: SnmpEJB/src/com/clustercontrol/snmp/bean/MonitorSnmpInfo.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.snmp.bean;

import com.clustercontrol.bean.ConvertValueConstant;
import com.clustercontrol.bean.SnmpVersionConstant;
import com.clustercontrol.monitor.run.bean.MonitorCheckInfo;

/**
 * SNMP監視情報クラスです。
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class MonitorSnmpInfo extends MonitorCheckInfo
{
	protected java.lang.String communityName;
	protected java.lang.Integer convertFlg = Integer.valueOf(ConvertValueConstant.TYPE_DELTA);
	protected java.lang.String snmpOid;
	protected java.lang.Integer snmpPort;
	protected java.lang.String snmpVersion = SnmpVersionConstant.STRING_V1;
	
   public MonitorSnmpInfo()
   {
   }

   public java.lang.String getCommunityName()
   {
      return this.communityName;
   }
   public void setCommunityName( java.lang.String communityName )
   {
      this.communityName = communityName;
   }
   
   public java.lang.Integer getConvertFlg()
   {
      return this.convertFlg;
   }
   public void setConvertFlg( java.lang.Integer convertFlg )
   {
      this.convertFlg = convertFlg;
   }

   public java.lang.String getSnmpOid()
   {
      return this.snmpOid;
   }
   public void setSnmpOid( java.lang.String snmpOid )
   {
      this.snmpOid = snmpOid;
   }
   
   public java.lang.Integer getSnmpPort()
   {
	  return this.snmpPort;
   }
   public void setSnmpPort( java.lang.Integer snmpPort )
   {
      this.snmpPort = snmpPort;
   }
   
   public java.lang.String getSnmpVersion()
   {
	  return this.snmpVersion;
   }
   public void setSnmpVersion( java.lang.String snmpVersion )
   {
      this.snmpVersion = snmpVersion;
   }
}
